@@ -1,7 +1,7 @@
 # ABSTRACT: The base class for all IO::Storm Bolts.
 
 package IO::Storm::Bolt;
-$IO::Storm::Bolt::VERSION = '0.15';
+$IO::Storm::Bolt::VERSION = '0.16';
 # Imports
 use strict;
 use warnings;
@@ -12,7 +12,6 @@ use Try::Tiny;
 use Moo;
 use namespace::clean;
 
-
 extends 'IO::Storm::Component';
 
 # A boolean indicating whether or not the bolt should automatically
@@ -46,17 +45,14 @@ has '_current_tups' => (
     init_arg => undef
 );
 
-
 sub initialize {
     my ( $self, $storm_conf, $context ) = @_;
 }
 
-
 sub process {
     my ( $self, $tuple ) = @_;
 }
 
-
 sub emit ($$;$) {
     my ( $self, $tuple, $args ) = @_;
 
@@ -68,11 +64,10 @@ sub emit ($$;$) {
         $anchors = $self->_current_tups // [];
     }
     unless ( defined( $args->{anchors} ) ) {
-    	$args->{anchors} = $anchors;
+        $args->{anchors} = $anchors;
     }
 
-    my $a;
-    for $a ( @{ $args->{anchors} } ) {
+    for my $a ( @{ $args->{anchors} } ) {
         if ( ref($a) eq "IO::Storm::Tuple" ) {
             $a = $a->id;
         }
@@ -99,7 +94,6 @@ sub emit ($$;$) {
     }
 }
 
-
 sub ack {
     my ( $self, $tuple ) = @_;
     my $tup_id;
@@ -112,7 +106,6 @@ sub ack {
     $self->send_message( { command => 'ack', id => $tup_id } );
 }
 
-
 sub fail {
     my ( $self, $tuple ) = @_;
     my $tup_id;
@@ -126,7 +119,6 @@ sub fail {
     $self->send_message( { command => 'fail', id => $tup_id } );
 }
 
-
 sub run {
     my ($self) = @_;
     my $tup;
@@ -139,9 +131,15 @@ sub run {
         while (1) {
             $tup = $self->read_tuple();
             $self->_current_tups( [$tup] );
-            $self->process($tup);
-            if ( $self->auto_ack ) {
-                $self->ack($tup);
+            if ( $tup->{task} == -1 && $tup->{stream} == '__heartbeat' ) {
+                $self->send_message( { command => 'sync' } );
+            }
+            else {
+                $self->process($tup);
+                if ( $self->auto_ack ) {
+                    $self->ack($tup);
+                }
+
             }
 
             # reset so that we don't accidentally fail the wrong tuples
@@ -174,7 +172,7 @@ IO::Storm::Bolt - The base class for all IO::Storm Bolts.
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 NAME
 
